@@ -5,12 +5,12 @@ from __future__ import annotations
 import logging
 import os
 import sys
-from sysconfig import get_platform, get_python_version
+from pkgutil import resolve_name
 from typing import ClassVar
 
 from setuptools import Command
 
-from cx_Freeze._compat import IS_WINDOWS
+from cx_Freeze._compat import BUILD_EXE_DIR, IS_WINDOWS
 from cx_Freeze.common import normalize_to_list
 from cx_Freeze.exception import OptionError, SetupError
 from cx_Freeze.freezer import Freezer
@@ -18,6 +18,8 @@ from cx_Freeze.module import ConstantsModule
 
 __all__ = ["build_exe"]
 
+logger = logging.getLogger(__name__)
+
 
 class build_exe(Command):
     """Build executables from Python scripts."""
@@ -46,8 +48,9 @@ class build_exe(Command):
         (
             "path=",
             None,
-            "comma-separated list of paths to search for modules; the default "
-            "value is sys.path (use only if you know what you are doing)",
+            "comma-separated list of paths to search for modules "
+            "(use only if you know what you are doing) "
+            "[default: sys.path]",
         ),
         (
             "include-path=",
@@ -138,7 +141,16 @@ class build_exe(Command):
         (
             "include-msvcr",
             None,
-            "include the Microsoft Visual C runtime files",
+            "include the Microsoft Visual C++ Redistributable "
+            "files without needing the redistributable package "
+            "installed (equivalent to --include-msvcr-version=17)",
+        ),
+        (
+            "include-msvcr-version=",
+            None,
+            "like --include-msvcr but the version can be set "
+            "with one of the following values: 15, 16 or 17 "
+            "(version 15 includes UCRT for Windows 8.1 and below)",
         ),
     ]
     boolean_options: ClassVar[list[str]] = [
@@ -165,9 +177,9 @@ class build_exe(Command):
         if command.compiler is not None:
             script_args.append(f"--compiler={command.compiler}")
         os.chdir(source_dir)
-        logging.info("building '%s' extension in '%s'", name, source_dir)
-        distutils_core = __import__("distutils.core", fromlist=["run_setup"])
-        distribution = distutils_core.run_setup("setup.py", script_args)
+        logger.info("building '%s' extension in '%s'", name, source_dir)
+        run_setup = resolve_name("distutils.core.run_setup")
+        distribution = run_setup("setup.py", script_args)
         ext_modules = distribution.ext_modules
         modules = [m for m in ext_modules if m.name == module_name]
         if not modules:
@@ -212,6 +224,7 @@ class build_exe(Command):
 
         self.build_exe = None
         self.include_msvcr = None
+        self.include_msvcr_version = None
         self.no_compress = False
         self.optimize = 0
         self.path = None
@@ -236,8 +249,7 @@ class build_exe(Command):
             msg = "build_exe option cannot be the same as build_base directory"
             raise SetupError(msg)
         if not self.build_exe:  # empty or None
-            dir_name = f"exe.{get_platform()}-{get_python_version()}"
-            self.build_exe = os.path.join(self.build_base, dir_name)
+            self.build_exe = os.path.join(self.build_base, BUILD_EXE_DIR.name)
 
         # make sure all options of multiple values are lists
         for option in self.list_options:
@@ -264,19 +276,27 @@ class build_exe(Command):
             self.zip_filename = "library.zip"
 
         # include-msvcr is used on Windows, but not in MingW
-        self.include_msvcr = IS_WINDOWS and bool(self.include_msvcr)
+        if IS_WINDOWS:
+            if self.include_msvcr_version is not None:
+                self.include_msvcr = True
+            self.include_msvcr = bool(self.include_msvcr)
+        else:
+            self.include_msvcr = False
 
         # optimization level: 0,1,2
         self.optimize = int(self.optimize or 0)
 
     def run(self) -> None:
+        executables = self.distribution.executables
         metadata = self.distribution.metadata
         constants_module = ConstantsModule(
-            metadata.version, constants=self.constants
+            metadata.version,
+            executables[0].copyright,
+            constants=self.constants,
         )
 
         freezer: Freezer = Freezer(
-            self.distribution.executables,
+            executables,
             constants_module,
             self.includes,
             self.excludes,
@@ -297,6 +317,7 @@ class build_exe(Command):
             silent=self.silent,
             metadata=metadata,
             include_msvcr=self.include_msvcr,
+            include_msvcr_version=self.include_msvcr_version,
             zip_filename=self.zip_filename,
         )
 
