@@ -30,12 +30,12 @@ from cx_Freeze._compat import (
     IS_WINDOWS,
     PYTHON_VERSION,
 )
-from cx_Freeze.common import get_resource_file_path, process_path_specs
+from cx_Freeze.common import process_path_specs, resource_path
+from cx_Freeze.dep_parser import ELFParser, Parser, PEParser
 from cx_Freeze.exception import FileError, OptionError
 from cx_Freeze.executable import Executable
 from cx_Freeze.finder import ModuleFinder
 from cx_Freeze.module import ConstantsModule, DistributionCache, Module
-from cx_Freeze.parser import ELFParser, Parser, PEParser
 
 if TYPE_CHECKING:
     from collections.abc import Mapping, Sequence
@@ -113,11 +113,13 @@ class Freezer:
         zip_exclude_packages: Sequence[str] | None = None,
         zip_filename: Path | str | None = None,
     ) -> None:
-        self.executables: list[Executable] = self._validate_executables(
-            executables
-        )
+        executables = self._validate_executables(executables)
+        self.executables: list[Executable] = executables
         if constants_module is None:
-            constants_module = ConstantsModule()
+            constants_module = ConstantsModule(
+                metadata.version if metadata else None,
+                executables[0].copyright,
+            )
         self.constants_module: ConstantsModule = constants_module
         self.includes: list[str] = list(includes or [])
         self.excludes: list[str] = list(excludes or [])
@@ -312,8 +314,7 @@ class Freezer:
         """Post-copy task."""
 
     def _create_directory(self, path: str | Path) -> None:
-        if isinstance(path, str):
-            path = Path(path)
+        path = Path(path)
         if not path.is_dir():
             if self.silent < 1:
                 print(f"creating directory {path}")
@@ -324,7 +325,7 @@ class Freezer:
         finder.include_file_as_module(exe.main_script, exe.main_module_name)
         finder.include_file_as_module(exe.init_script, exe.init_module_name)
         finder.include_file_as_module(
-            get_resource_file_path("initscripts", "__startup__", ".py")
+            resource_path("initscripts/__startup__.py")
         )
 
         # copy the executable and its dependencies
@@ -338,9 +339,7 @@ class Freezer:
             target_path.chmod(mode | stat.S_IWUSR)
 
         # copy a file with a the cx_freeze license into frozen application
-        respath = get_resource_file_path(
-            "initscripts", "frozen_application_license", ".txt"
-        )
+        respath = resource_path("initscripts/frozen_application_license.txt")
         if respath is None:
             msg = "Unable to find license for frozen application."
             raise FileError(msg)
@@ -515,7 +514,7 @@ class Freezer:
         modules when it differs from the running python built-in modules.
         """
         path = list(map(os.path.normpath, path or sys.path))
-        dynload = get_resource_file_path("bases", "lib-dynload", "")
+        dynload = resource_path("bases/lib-dynload")
         if dynload and dynload.is_dir():
             # add bases/lib-dynload to the finder path, if has modules
             ext_suffix = sysconfig.get_config_var("EXT_SUFFIX")
@@ -722,12 +721,13 @@ class Freezer:
             # write any files to the zip file that were requested specially
             for source_path, target_path in finder.zip_includes:
                 if source_path.is_dir():
-                    pos = len(source_path.as_posix()) + 1
                     for source_filename in source_path.rglob("*"):
                         if source_filename.is_dir():
                             continue
-                        target = target_path / source_filename.as_posix()[pos:]
-                        outfile.write(source_filename, target)
+                        target = target_path.joinpath(
+                            source_filename.relative_to(source_path)
+                        )
+                        outfile.write(source_filename, target.as_posix())
                 else:
                     outfile.write(source_path, target_path.as_posix())
 
@@ -1147,7 +1147,7 @@ class DarwinFreezer(Freezer, Parser):
 
     def _default_bin_path_includes(self) -> list[str]:
         # use macpython distributed files if available
-        bases_lib = get_resource_file_path("bases", "lib", "")
+        bases_lib = resource_path("bases/lib")
         if bases_lib:
             return self._validate_bin_path([bases_lib])
         # use default
