@@ -8,24 +8,21 @@ import zmq
 
 
 class ignore(AbstractContextManager):
-    def __init__(self, call):
+    def __init__(self, call) -> None:
         self.call = call
 
-    def __enter__(self):
+    def __enter__(self):  # noqa: ANN204
         if hasattr(self.call, "__enter__"):
             return self.call
         return self
 
-    def __exit__(self, *exc_info):
+    def __exit__(self, *exc_info):  # noqa: ANN204
         if hasattr(self.call, "__exit__"):
             return self.call.__exit__
         return None
 
 
-if len(sys.argv) > 1:
-    port = int(sys.argv[1])
-else:
-    port = 5556
+port = int(sys.argv[1]) if len(sys.argv) > 1 else 5556
 
 url = f"tcp://*:{port}"
 reply = "Pong"
