@@ -3,21 +3,19 @@
 from __future__ import annotations
 
 import sys
-from pathlib import Path
 from shutil import which
 from subprocess import run
+from typing import TYPE_CHECKING
 
 import pytest
 from setuptools import Distribution
 
+from cx_Freeze._compat import IS_LINUX
+from cx_Freeze.command.bdist_deb import bdist_deb
 from cx_Freeze.exception import PlatformError
 
-bdist_deb = pytest.importorskip(
-    "cx_Freeze.command.bdist_deb", reason="Linux tests"
-).bdist_deb
-
-if sys.platform != "linux":
-    pytest.skip(reason="Linux tests", allow_module_level=True)
+if TYPE_CHECKING:
+    from pathlib import Path
 
 DIST_ATTRS = {
     "name": "foo",
@@ -29,18 +27,20 @@ DIST_ATTRS = {
     "author_email": "marcelotduarte@users.noreply.github.com",
     "url": "https://github.com/marcelotduarte/cx_Freeze/",
 }
-SAMPLES_DIR = Path(__file__).resolve().parent.parent / "samples"
 
 
-def test_bdist_deb_not_posix(monkeypatch) -> None:
-    """Test the bdist_deb fail if not on posix."""
+@pytest.mark.skipif(IS_LINUX, reason="Test not on Linux platform")
+def test_bdist_deb_not_posix() -> None:
+    """Test the bdist_deb fail if not on Linux."""
     dist = Distribution(DIST_ATTRS)
     cmd = bdist_deb(dist)
-    monkeypatch.setattr("os.name", "nt")
-    with pytest.raises(PlatformError, match="don't know how to create DEB"):
+    with pytest.raises(
+        PlatformError, match="bdist_deb is supported only on Linux"
+    ):
         cmd.finalize_options()
 
 
+@pytest.mark.skipif(not IS_LINUX, reason="Linux test")
 def test_bdist_deb_not_alien(monkeypatch) -> None:
     """Test the bdist_deb uses alien."""
     dist = Distribution(DIST_ATTRS)
@@ -50,6 +50,7 @@ def test_bdist_deb_not_alien(monkeypatch) -> None:
         cmd.finalize_options()
 
 
+@pytest.mark.skipif(not IS_LINUX, reason="Linux test")
 def test_bdist_deb_not_fakeroot(monkeypatch) -> None:
     """Test the bdist_deb uses fakeroot."""
     dist = Distribution(DIST_ATTRS)
@@ -60,6 +61,7 @@ def test_bdist_deb_not_fakeroot(monkeypatch) -> None:
         cmd.finalize_options()
 
 
+@pytest.mark.skipif(not IS_LINUX, reason="Linux test")
 def test_bdist_deb_dry_run(monkeypatch, tmp_path: Path) -> None:
     """Test the bdist_deb dry_run."""
     monkeypatch.chdir(tmp_path)
@@ -75,19 +77,20 @@ def test_bdist_deb_dry_run(monkeypatch, tmp_path: Path) -> None:
     cmd.run()
 
 
-@pytest.mark.datafiles(SAMPLES_DIR / "simple")
-def test_bdist_deb_simple(datafiles: Path) -> None:
+@pytest.mark.skipif(not IS_LINUX, reason="Linux test")
+def test_bdist_deb_simple(tmp_package) -> None:
     """Test the simple sample with bdist_deb."""
     name = "hello"
     version = "0.1.2.3"
-    dist_created = datafiles / "dist"
+    dist_created = tmp_package.path / "dist"
 
+    tmp_package.create_from_sample("simple")
     process = run(
         [sys.executable, "setup.py", "bdist_deb"],
         text=True,
         capture_output=True,
         check=False,
-        cwd=datafiles,
+        cwd=tmp_package.path,
     )
     if process.returncode != 0:
         msg = process.stderr
@@ -104,20 +107,21 @@ def test_bdist_deb_simple(datafiles: Path) -> None:
     assert file_created.is_file(), pattern
 
 
-@pytest.mark.datafiles(SAMPLES_DIR / "simple_pyproject")
-def test_bdist_deb_simple_pyproject(datafiles: Path) -> None:
+@pytest.mark.skipif(not IS_LINUX, reason="Linux test")
+def test_bdist_deb_simple_pyproject(tmp_package) -> None:
     """Test the simple_pyproject sample with bdist_deb."""
     name = "hello"
     version = "0.1.2.3"
-    dist_created = datafiles / "dist"
+    dist_created = tmp_package.path / "dist"
 
+    tmp_package.create_from_sample("simple_pyproject")
     cxfreeze = which("cxfreeze")
     process = run(
         [cxfreeze, "bdist_deb"],
         text=True,
         capture_output=True,
         check=False,
-        cwd=datafiles,
+        cwd=tmp_package.path,
     )
     if process.returncode != 0:
         msg = process.stderr
@@ -134,19 +138,20 @@ def test_bdist_deb_simple_pyproject(datafiles: Path) -> None:
     assert file_created.is_file(), pattern
 
 
-@pytest.mark.datafiles(SAMPLES_DIR / "sqlite")
-def test_bdist_deb(datafiles: Path) -> None:
+@pytest.mark.skipif(not IS_LINUX, reason="Linux test")
+def test_bdist_deb(tmp_package) -> None:
     """Test the sqlite sample with bdist_deb."""
     name = "test_sqlite3"
     version = "0.5"
-    dist_created = datafiles / "dist2"
+    dist_created = tmp_package.path / "dist2"
 
+    tmp_package.create_from_sample("sqlite")
     process = run(
         [sys.executable, "setup.py", "bdist_deb", "--dist-dir", dist_created],
         text=True,
         capture_output=True,
         check=False,
-        cwd=datafiles,
+        cwd=tmp_package.path,
     )
     if process.returncode != 0:
         msg = process.stderr
