@@ -4,25 +4,16 @@ from __future__ import annotations
 
 import shutil
 import sys
+from importlib.resources import files
 from pathlib import Path
 
 import pytest
-from generate_samples import create_package, run_command
 from setuptools import Distribution
 
 from cx_Freeze import Executable
-from cx_Freeze._compat import (
-    ABI_THREAD,
-    BUILD_EXE_DIR,
-    EXE_SUFFIX,
-    IS_MACOS,
-    IS_MINGW,
-    IS_WINDOWS,
-)
+from cx_Freeze._compat import EXE_SUFFIX, IS_MINGW, IS_WINDOWS, SOABI
 from cx_Freeze.exception import OptionError, SetupError
 
-TOP_DIR = Path(__file__).resolve().parent.parent
-
 SOURCE_SETUP_TOML = """
 test_1.py
     print("Hello from cx_Freeze")
@@ -43,7 +34,7 @@ pyproject.toml
     excludes = ["tkinter", "unittest"]
     silent = true
 command
-    cxfreeze build_exe --excludes=tkinter
+    cxfreeze build_exe
 """
 
 SOURCE_SETUP_PY = """
@@ -81,7 +72,7 @@ setup.cfg
     excludes = tkinter,unittest
     silent = true
 command
-    cxfreeze test_1.py
+    cxfreeze --script test_1.py
 """
 
 SOURCE_SETUP_MIX = """
@@ -213,70 +204,109 @@ command
     ],
 )
 def test_executables(
-    tmp_path: Path, source: str, number_of_executables: int
+    tmp_package, source: str, number_of_executables: int
 ) -> None:
     """Test the executables option."""
-    create_package(tmp_path, source)
-    output = run_command(tmp_path)
+    tmp_package.create(source)
+    output = tmp_package.run()
 
     for i in range(1, number_of_executables):
-        file_created = tmp_path / BUILD_EXE_DIR / f"test_{i}{EXE_SUFFIX}"
+        file_created = tmp_package.executable(f"test_{i}")
         assert file_created.is_file(), f"file not found: {file_created}"
 
-        output = run_command(tmp_path, file_created, timeout=10)
+        output = tmp_package.run(file_created, timeout=10)
         assert output.startswith("Hello from cx_Freeze")
 
 
 TEST_VALID_PARAMETERS = [
-    ("base", "console", "console-"),
-    ("init_script", None, "console.py"),
+    ("base", "console", f"console-{SOABI}{EXE_SUFFIX}"),
+    pytest.param(
+        "base",
+        "absolutepath",
+        f"console_test{EXE_SUFFIX}",
+        id="base-absolutepath-console_test",
+    ),
+    pytest.param(
+        "init_script", None, "console.py", id="init_script-none-console.py"
+    ),
     ("init_script", "console", "console.py"),
-    ("target_name", None, f"test{EXE_SUFFIX}"),
+    pytest.param(
+        "init_script",
+        "absolutepath",
+        "console_test.py",
+        id="init_script-absolutepath-console_test.py",
+    ),
+    pytest.param(
+        "target_name", None, f"test{EXE_SUFFIX}", id="target_name-none-test"
+    ),
     ("target_name", "test1", f"test1{EXE_SUFFIX}"),
     ("target_name", "12345", f"12345{EXE_SUFFIX}"),
     ("target_name", "test-0.1", f"test-0.1{EXE_SUFFIX}"),
     ("target_name", "test.exe", "test.exe"),
-    (
+    pytest.param(
         "icon",
         "icon",
         ("icon.ico", "icon.icns", "icon.png", "icon.svg"),
+        id="icon-icon-multiple",
     ),
 ]
-if (
-    sys.version_info[:2] <= (3, 13)
-    and ABI_THREAD == ""
-    and not (IS_MACOS and sys.version_info[:2] == (3, 13))
-):
+if sys.version_info[:2] < (3, 13):
     TEST_VALID_PARAMETERS += [
-        ("base", None, "console_legacy-"),
-        ("base", "console_legacy", "console_legacy-"),
+        pytest.param(
+            "base",
+            None,
+            f"console_legacy-{SOABI}{EXE_SUFFIX}",
+            id="base-none-console_legacy-",
+        ),
+        ("base", "console_legacy", f"console_legacy-{SOABI}{EXE_SUFFIX}"),
     ]
 else:
     TEST_VALID_PARAMETERS += [
-        ("base", None, "console-"),
+        pytest.param(
+            "base",
+            None,
+            f"console-{SOABI}{EXE_SUFFIX}",
+            id="base-none-console-",
+        ),
     ]
 if IS_WINDOWS or IS_MINGW:
     TEST_VALID_PARAMETERS += [
-        ("base", "gui", "gui-"),
-        ("base", "service", "service-"),
-        ("base", "Win32GUI", "Win32GUI-"),
-        ("base", "Win32Service", "Win32Service-"),
+        ("base", "gui", f"gui-{SOABI}{EXE_SUFFIX}"),
+        ("base", "service", f"service-{SOABI}{EXE_SUFFIX}"),
+        ("base", "Win32GUI", f"Win32GUI-{SOABI}{EXE_SUFFIX}"),
+        ("base", "Win32Service", f"Win32Service-{SOABI}{EXE_SUFFIX}"),
     ]
 else:
     TEST_VALID_PARAMETERS += [
-        ("base", "gui", "console-"),
-        ("base", "service", "console-"),
+        ("base", "gui", f"console-{SOABI}{EXE_SUFFIX}"),
+        ("base", "service", f"console-{SOABI}{EXE_SUFFIX}"),
     ]
 
 
 @pytest.mark.parametrize(("option", "value", "result"), TEST_VALID_PARAMETERS)
-def test_valid(option, value, result) -> None:
+def test_valid(tmp_package, option, value, result) -> None:
     """Test valid values to use in Executable class."""
+    if value == "absolutepath":
+        src_dir = files("cx_Freeze").resolve()
+        if option == "base":
+            value = tmp_package.path / f"console_test{EXE_SUFFIX}"
+            shutil.copyfile(
+                src_dir / f"bases/console-{SOABI}{EXE_SUFFIX}", value
+            )
+        elif option == "init_script":
+            value = tmp_package.path / "console_test.py"
+            shutil.copyfile(src_dir / "initscripts/console.py", value)
+
     executable = Executable("test.py", **{option: value})
     returned = getattr(executable, option)
+    if isinstance(value, Path) and value.is_absolute():
+        assert returned == value
     if isinstance(returned, Path):
         returned = returned.name
-    assert returned.startswith(result), returned
+    if isinstance(result, tuple):  # valid icon names
+        assert returned.startswith(result), returned
+        return
+    assert returned == result, returned
 
 
 @pytest.mark.parametrize(
@@ -318,7 +348,7 @@ def test_valid(option, value, result) -> None:
         "executables-invalid-string",
         "executable-invalid-base",
         "executable-invalid-init_script",
-        "executable-invalid-target_name",
+        "executable-invalid-target_name-with-path",
     ],
 )
 def test_invalid(
@@ -344,32 +374,34 @@ pyproject.toml
 
     [tool.cxfreeze.build_exe]
     excludes = ["tkinter", "unittest"]
-command
-    cxfreeze build
+    silent = false
 """
 
 
-def test_valid_icon(tmp_path: Path) -> None:
+def test_valid_icon(tmp_package) -> None:
     """Test with valid icon in any OS."""
-    create_package(tmp_path, SOURCE_VALID_ICON)
-    # copy valid icons
-    for src in TOP_DIR.joinpath("cx_Freeze/icons").glob("py.*"):
-        shutil.copyfile(src, tmp_path.joinpath("icon").with_suffix(src.suffix))
-    output = run_command(tmp_path)
+    tmp_package.create(SOURCE_VALID_ICON)
+    # copy valid icons: cp $SRC/cx_Freeze/icons/py.* $DST/icon.*
+    src_dir = files("cx_Freeze").resolve()
+    for src in src_dir.joinpath("icons").glob("py.*"):
+        shutil.copyfile(
+            src, tmp_package.path.joinpath("icon").with_suffix(src.suffix)
+        )
+    output = tmp_package.run()
     assert "WARNING: Icon file not found" not in output, "icon file not found"
 
-    file_created = tmp_path / BUILD_EXE_DIR / f"test_icon{EXE_SUFFIX}"
+    file_created = tmp_package.executable("test_icon")
     assert file_created.is_file(), f"file not found: {file_created}"
 
-    output = run_command(tmp_path, file_created, timeout=10)
+    output = tmp_package.run(file_created, timeout=10)
     assert output.startswith("Hello from cx_Freeze")
 
 
-def test_not_found_icon(tmp_path: Path) -> None:
+def test_not_found_icon(tmp_package) -> None:
     """Test with not found icon in any OS."""
     # same test as before, without icons
-    create_package(tmp_path, SOURCE_VALID_ICON)
-    output = run_command(tmp_path)
+    tmp_package.create(SOURCE_VALID_ICON)
+    output = tmp_package.run()
     assert "WARNING: Icon file not found" in output, "icon file not found"
 
 
@@ -388,17 +420,18 @@ pyproject.toml
 
     [tool.cxfreeze.build_exe]
     excludes = ["tkinter", "unittest"]
-command
-    cxfreeze build
+    silent = false
 """
 
 
 @pytest.mark.skipif(not (IS_MINGW or IS_WINDOWS), reason="Windows tests")
-def test_invalid_icon(tmp_path: Path) -> None:
+def test_invalid_icon(tmp_package) -> None:
     """Test with invalid icon in Windows."""
-    create_package(tmp_path, SOURCE_INVALID_ICON)
-    shutil.copyfile(TOP_DIR / "cx_Freeze/icons/py.png", tmp_path / "icon.png")
-    output = run_command(tmp_path)
+    tmp_package.create(SOURCE_INVALID_ICON)
+    # use an invalid icon: cp $SRC/cx_Freeze/icons/py.png $DST/icon.png
+    src_dir = files("cx_Freeze").resolve()
+    shutil.copyfile(src_dir / "icons/py.png", tmp_package.path / "icon.png")
+    output = tmp_package.run()
     assert "WARNING: Icon file not found" not in output, "icon file not found"
     # it is expected the folowing warning if the icon is invalid
     assert "WARNING: Icon filename 'icon.png' has invalid type." in output
@@ -418,25 +451,22 @@ pyproject.toml
 
     [tool.cxfreeze.build_exe]
     excludes = ["tkinter", "unittest"]
-command
-    cxfreeze build
+    silent = true
 """
 
 
-def test_executable_rename(tmp_path: Path) -> None:
+def test_executable_rename(tmp_package) -> None:
     """Test if the executable can be renamed."""
-    create_package(tmp_path, SOURCE_RENAME)
-    output = run_command(tmp_path)
-    file_created = tmp_path / BUILD_EXE_DIR / f"test_0{EXE_SUFFIX}"
+    tmp_package.create(SOURCE_RENAME)
+    output = tmp_package.run()
+    file_created = tmp_package.executable("test_0")
     assert file_created.is_file(), f"file not found: {file_created}"
 
-    output = run_command(tmp_path, file_created, timeout=10)
+    output = tmp_package.run(file_created, timeout=10)
     assert output.startswith("Hello from cx_Freeze")
 
-    file_renamed = file_created.rename(
-        file_created.parent / "test_zero{EXE_SUFFIX}"
-    )
-    output = run_command(tmp_path, file_renamed, timeout=10)
+    file_renamed = file_created.rename(file_created.parent / "test_zero")
+    output = tmp_package.run(file_renamed, timeout=10)
     assert output.startswith("Hello from cx_Freeze")
 
 
@@ -504,7 +534,7 @@ command
     ],
 )
 def test_executable_namespace(
-    tmp_path: Path,
+    tmp_package,
     source: str,
     hello: int,
     namespace: int,
@@ -512,16 +542,16 @@ def test_executable_namespace(
     zip_packages: bool,
 ) -> None:
     """Test executable with namespace package."""
-    create_package(tmp_path, source)
+    tmp_package.create(source)
     if zip_packages:
-        with tmp_path.joinpath("command").open("a") as f:
+        with tmp_package.path.joinpath("command").open("a") as f:
             f.write(" --zip-include-packages=* --zip-exclude-packages=")
-    output = run_command(tmp_path)
+    output = tmp_package.run()
 
-    file_created = tmp_path / BUILD_EXE_DIR / f"test{EXE_SUFFIX}"
+    file_created = tmp_package.executable("test")
     assert file_created.is_file(), f"file not found: {file_created}"
 
-    output = run_command(tmp_path, file_created, timeout=10)
+    output = tmp_package.run(file_created, timeout=10)
     lines = output.splitlines()
     start = 0
     stop = hello
