@@ -2,15 +2,13 @@
 
 from __future__ import annotations
 
-import sys
 from pathlib import Path
 from subprocess import CalledProcessError
 
 import pytest
-from generate_samples import create_package, run_command
 from packaging.version import Version
 
-from cx_Freeze._compat import BUILD_EXE_DIR
+from cx_Freeze._compat import EXE_SUFFIX, IS_MINGW, IS_WINDOWS
 from cx_Freeze.winversioninfo import COMMENTS_MAX_LEN, VersionInfo, main_test
 
 SOURCE_SIMPLE_TEST = """
@@ -28,7 +26,7 @@ setup.py
 """
 
 
-@pytest.mark.skipif(sys.platform != "win32", reason="Windows tests")
+@pytest.mark.skipif(not (IS_MINGW or IS_WINDOWS), reason="Windows tests")
 class TestVersionInfo:
     """Test VersionInfo class."""
 
@@ -123,27 +121,13 @@ class TestVersionInfo:
         """
         default_version = VersionInfo(input_version)
         assert default_version.version == version
-        assert default_version.version_info(Path("test.exe"))
+        assert default_version.version_info(Path(f"test{EXE_SUFFIX}"))
 
     def test_file_not_found(self) -> None:
         """Test for FileNotFoundError exception."""
         version = VersionInfo("0.1")
         with pytest.raises(FileNotFoundError):
-            version.stamp("test.exe")
-
-    @pytest.fixture
-    def tmp_test(self, tmp_path) -> Path:
-        """Generate a executable file test.exe to be used in tests."""
-        create_package(tmp_path, SOURCE_SIMPLE_TEST)
-        run_command(tmp_path)
-
-        file_created = tmp_path / BUILD_EXE_DIR / "test.exe"
-        assert file_created.is_file(), f"file not found: {file_created}"
-
-        output = run_command(tmp_path, file_created, timeout=10)
-        assert output.startswith("Hello from cx_Freeze")
-
-        return file_created
+            version.stamp(f"test{EXE_SUFFIX}")
 
     @pytest.mark.parametrize(
         "option",
@@ -153,9 +137,21 @@ class TestVersionInfo:
             pytest.param("--pywin32", marks=pytest.mark.xfail),
         ],
     )
-    def test_main(self, tmp_test, option, capsys) -> None:
+    def test_main(self, tmp_package, option, capsys) -> None:
         """Test the cx_Freeze.winversioninfo __main_ entry point."""
-        main_test(args=["--version=0.2", option, f"{tmp_test}"])
+        tmp_package.create(SOURCE_SIMPLE_TEST)
+        if option == "--pywin32":
+            tmp_package.monkeypatch.setenv("CX_FREEZE_STAMP", "pywin32")
+            tmp_package.install("pywin32", isolated=False)
+        tmp_package.run()
+
+        executable = tmp_package.executable("test")
+        assert executable.is_file(), f"file not found: {executable}"
+
+        output = tmp_package.run(executable, timeout=10)
+        assert output.startswith("Hello from cx_Freeze")
+
+        main_test(args=["--version=0.2", option, f"{executable}"])
         captured = capsys.readouterr()
         assert captured.out.splitlines()[-1].startswith("Stamped:")
 
@@ -164,8 +160,10 @@ class TestVersionInfo:
         with pytest.raises(SystemExit):
             main_test(args=[])
 
-    def test_main_with_environ(self, tmp_test, monkeypatch) -> None:
+    def test_main_with_environ(self, tmp_package) -> None:
         """Test argparse error exception."""
-        monkeypatch.setenv("CX_FREEZE_STAMP", "pywin32")
+        # pywin32 must be installed on venv
+        tmp_package.install("pywin32", isolated=False)
+        tmp_package.monkeypatch.setenv("CX_FREEZE_STAMP", "pywin32")
         with pytest.raises(CalledProcessError):
-            run_command(tmp_test.parent, "python -m cx_Freeze.winversioninfo")
+            tmp_package.run("python -m cx_Freeze.winversioninfo")
